summaryrefslogtreecommitdiffstats
path: root/superkaramba/src/widget_python.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-23 01:42:07 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-23 01:42:07 +0000
commita2277b6bc715464e83882b90c2a058139b8a6b54 (patch)
treeab09b14014f59b4d8e2ddd12226aa0b22e4dfc5d /superkaramba/src/widget_python.h
parentd3f79e04b34bd1f70a458b81b28fc8799498c8dc (diff)
downloadtdeutils-a2277b6bc715464e83882b90c2a058139b8a6b54.tar.gz
tdeutils-a2277b6bc715464e83882b90c2a058139b8a6b54.zip
TQt4 port kdeutils
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeutils@1238125 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'superkaramba/src/widget_python.h')
-rw-r--r--superkaramba/src/widget_python.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/superkaramba/src/widget_python.h b/superkaramba/src/widget_python.h
index 97cc263..e54c31d 100644
--- a/superkaramba/src/widget_python.h
+++ b/superkaramba/src/widget_python.h
@@ -42,17 +42,17 @@ PyObject* py_get_widget_position(PyObject *self, PyObject *args);
/** Widget/createWidgetMask
*
* SYNOPSIS
-* long createWidgetMask(widget, mask)
+* long createWidgetMask(widget, tqmask)
* DESCRIPTION
* This function doesn't work currently due to a bug in KDE. Please use
* MASK= in your .theme file for the time being.
* ARGUMENTS
* * long widget -- karamba
* * string mask -- The name of the widget mask file.
* RETURN VALUE
* 1 if successful
*/
-PyObject* py_create_widget_mask(PyObject *self, PyObject *args);
+PyObject* py_create_widget_tqmask(PyObject *self, PyObject *args);
/** Widget/redrawWidgetBackground
*
@@ -42,17 +42,17 @@ PyObject* py_get_widget_position(PyObject *self, PyObject *args);
* ARGUMENTS
* * long widget -- karamba
-* * string mask -- The name of the widget mask file.
+* * string tqmask -- The name of the widget tqmask file.
* RETURN VALUE
* 1 if successful